Lamin
=====

Data management for computational biology.

* Get started with these :doc:`guides <guides/index>`.
* Browse the full :doc:`API reference <api>`.


.. toctree::
   :maxdepth: 1
   :hidden:

   api
   guides/index
   notes/index
